/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model.sinfo;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;


/**
 * Hibernate binding for the DB table flow_depth_values
 *
 * @author Matthias Schäfer
 *
 */
@Entity
@Table(name = "flow_depth_values")
public class FlowDepthValue implements Serializable {

    /***** FIELDS *****/

    private static final long serialVersionUID = -7465899199734466657L;

    private Integer id;

    private FlowDepthColumn flowDepthColumn;

    private Double station;

    /**
     * Flow depth in m
     */
    private Double depth;


    /***** CONSTRUCTORS *****/

    public FlowDepthValue() {
    }

    public FlowDepthValue(final FlowDepthColumn flowDepthColumn, final Double station, final Double depth) {
        this.flowDepthColumn = flowDepthColumn;
        this.station = station;
        this.depth = depth;
    }

    /**
     * Constructor with primitive parameter types
     */
    public FlowDepthValue(final FlowDepthColumn flow_depthColumn, final double km, final double depth) {
        this(flow_depthColumn, Double.valueOf(km), Double.valueOf(depth));
    }


    /***** METHODS *****/

    @Id
    @SequenceGenerator(name = "SEQUENCE_FLOW_DEPTH_VALUE_ID_SEQ", sequenceName = "FLOW_DEPTH_VALUES_ID_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "SEQUENCE_FLOW_DEPTH_VALUE_ID_SEQ")
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "flow_depth_column_id")
    public FlowDepthColumn getFlowDepthColumn() {
        return this.flowDepthColumn;
    }

    public void setFlowDepthColumn(final FlowDepthColumn flow_depth) {
        this.flowDepthColumn = flow_depth;
    }

    @Column(name = "station")
    public Double getStation() {
        return this.station;
    }

    public void setStation(final Double station) {
        this.station = station;
    }

    @Column(name = "depth")
    public Double getDepth() {
        return this.depth;
    }

    public void setDepth(final Double depth) {
        this.depth = depth;
    }
}
